Struct Ciphertext
pub struct Ciphertext { /* private fields */ }Expand description
New owned buffer
Construct the reference version of this type through the algorithm API functions.
Optional support for serde if that feature is enabled.
Implementations
impl Ciphertext
impl Ciphertext